Current Term Opinion List - Supreme Court of Appeals of West Virginia
Description: All decisions filed in the current term of the Supreme Court of Appeals of West Virginia. The new integrated decision list combines all of the decisions issued during a court term, identified using case type and decision type codes.

- Skip to main menu
- Skip to main content

###### Opinion List Quick Tip

- AEach column of the list can be sorted by clicking the header of that column.
- BThe list-wide active text search or "List Search" allows the viewer to quickly search for specific information by typing a single word or multiple words, seperated by a space.
- CA drop down menu allows the user to change the humber of list items currently showing on the page.

For more detailed help on the new features of the Opinion List, download the overview by clicking here.

Open Help

# West Virginia Judiciary

## Opinions of the Supreme Court of Appeals

### Current Term Opinion List

Links to all decisions filed in the current term of court are listed in the table below. Are you looking for an opinion list from a prior term of court? If so, please visit the Information & Search page. Opinions from the September 1991 term of court to the present day are available online.

The new integrated decision list combines all of the decisions issued during a court term, identifed using case type and decision type codes. To re-sort the list quickly, click any of the column headers (except case number). For more information about using the decision list and for an explanation of the codes, review the page: About the Decision List.

QUICK TIP: For more help on using the opinion table, click the to the right on the page. When the page loads, the Date Filed column is sorted descending.

January 2012 Term of Court Opinions and Memorandum Decisions

January 2012 Term of Court Opinions and Memorandum Decisions
decision Type
Date Filed | Case No. | Case Name | Case Type | Decision Type
--- | --- | --- | --- | ---
3/12/2012 | 11-0368 | Lawrence E. Scible v. David Ballard, Warden | CIV-O | MD
3/12/2012 | 11-0432 | State of West Virginia v. Mark Wilson | CR-F | MD
3/12/2012 | 11-0433 | Keith R. Jeffers v. David Ballard, Warden | CIV-O | MD
3/12/2012 | 101571 | James Ward v. USA, Federal Bureau of Prisons | CIV-O | MD
3/12/2012 | 11-1474 | In the Interest of: K.H. | JUV | MD
3/12/2012 | 11-1365 | In the Interest of: E.M. | JUV | MD
3/12/2012 | 11-1317 | In the Interest of: T.M. | JUV | MD
3/12/2012 | 11-1263 | In the Interest of: B.H. | JUV | MD
3/12/2012 | 11-1165 | In the Interest of: J.M., C.H., B.H. and C.H., Jr. | JUV | MD
3/12/2012 | 101437 | Tex Gene Holbrook v. David Ballard, Warden | CIV-O | MD
3/12/2012 | 34359 | Bobby R. Hicks v. W. Va. Office of Insurance Commission/United Dairy | WC | MD
3/12/2012 | 11-1182 | In Re: M.D. and A.D. | JUV | MD
3/12/2012 | 11-1161 | In Re: I.A. and M.A. | JUV | MD
3/12/2012 | 11-1018 | In Re: M.M. Jr., S.M., E.M., A.M. and B.M. | JUV | MD
3/12/2012 | 11-0952 | In Re: M.M. Jr., S.M., E.M., A.M. and B.M. | JUV | MD
3/12/2012 | 11-0672 | Ray and Bette Kesling v. Sonshine, LLC | TCR | MD
3/12/2012 | 11-1102 | In Re: B.K. and J.K. | JUV | MD
3/12/2012 | 11-1089 | In Re: J.S. and K.S. | JUV | MD
3/12/2012 | 11-1088 | In Re: A.C., A.C., A.C. and A.C. | JUV | MD
3/12/2012 | 11-1086 | In Re: D.N. | JUV | MD
3/12/2012 | 11-1078 | In Re: J.N. | JUV | MD
3/12/2012 | 11-1026 | In Re: N.W. | JUV | MD
3/12/2012 | 11-0979 | In Re: P.D. and A.D. | JUV | MD
3/12/2012 | 11-0974 | In Re: D.C. and M.C. | JUV | MD
3/12/2012 | 11-0795 | Sara Jane Workman v. Carl Samuel Workman | FAM | MD
3/12/2012 | 11-0763 | D.G.L. v. D.K.L. | FAM | MD
3/12/2012 | 11-0709 | State of West Virginia v. J.S. | CR-O | MD
3/12/2012 | 11-0823 | Dana Waid Young, et al. v. Brian Waid, et al. | TCR | MD
3/12/2012 | 11-0922 | Burch Roofing and Construction v. Mark Poh, etc. | TCR | MD
3/12/2012 | 11-1568 | In Re: S.B. | JUV | MD
3/12/2012 | 11-1552 | In Re: A.D., K.D., D.D., K.P., A.P. and J.P. | JUV | MD
3/12/2012 | 11-1538 | In Re: D.N. | JUV | MD
3/12/2012 | 11-1518 | In Re: M.W. | JUV | MD
3/12/2012 | 11-1419 | In Re: S.W. | JUV | MD
3/12/2012 | 11-1364 | In Re: A.S., A.S., A.S.and K.S. | JUV | MD
3/12/2012 | 11-1338 | In Re: A.S., A.S., A.S.and K.S. | JUV | MD
3/12/2012 | 11-1266 | In Re: NB. and Z.B. | JUV | MD
3/12/2012 | 11-1150 | In Re: T.C., J.C., V.C., A.C., C.C., C.C. and E.C. | JUV | MD
3/12/2012 | 11-1403 | In Re: J.W., K.W., T.W. and M.S. | JUV | MD
3/12/2012 | 11-0774 | In Re: J.W., K.W., T.W. and M.S. | JUV | MD
3/12/2012 | 11-0857 | State of West Virginia v. Michael Marks | CR-F | MD
3/12/2012 | 11-1082 | Alvin Chambers v. David Ballard, Warden | CIV-O | MD
3/12/2012 | 11-0923 | Todd A. Hicks v. Brickstreet Mutual Insurance | TCR | MD
3/12/2012 | 11-0923 | Todd A. Hicks v. Brickstreet Mutual Insurance | TCR | MD
3/9/2012 | 11-0417 & 11-0794 | State of West Virginia v. Shawn J. Bailey | CR-F | MD
3/9/2012 | 11-0556 | State of West Virginia v. Shelley Ray Guthrie | CR-F | MD
3/9/2012 | 11-0663 | SER Roger Repass v. Adrian Hoke, Warden | CIV-O | MD
3/9/2012 | 11-0777 | State of West Virginia v. David Kestner | CR-F | MD
3/9/2012 | 11-0778 | Gary D. Lanham v. W. Va. Consolidated Public Retirement Board | ADM | MD
3/9/2012 | 11-0553 | In Re: The Adoption of Wesley G. | FAM | MD
3/9/2012 | 11-0702 | Melissa Sue Ennis(formerly Steele) v. Andrew Blair Cox | FAM | MD
3/9/2012 | 11-0814 | Travis Hough v. Boll Medical | CIV-O | MD
3/9/2012 | 11-0329 | Brent Childress v. W. Va. State Police, etc. | ADM | MD
3/9/2012 | 11-0237 | SER Andre King v. Jim Ielapi, Warden | CIV-O | MD
3/9/2012 | 11-0494 | SER William David Belcher v. Adrian Hoke, Warden | CIV-O | MD
3/9/2012 | 11-0593 | SER Ernest "Sonny" Tucker v. Thomas L. McBride, Warden | CIV-O | MD
3/9/2012 | 11-0988 | State of West Virginia v. J.D. Lambert | CR-F | MD
3/9/2012 | 11-0620 | State of West Virginia v. James Ellis Spuduck | CR-F | MD
3/1/2012 | 11-0592 | Rebuild America v. Mark E. Davis, et al. | TCR | SO
2/28/2012 | 11-0755 | In Re: Ashton M. (Workman, J., concurring, in part, and dissenting, in part) | JUV | SEP
2/28/2012 | 11-0755 | In Re: Ashton M. | JUV | PC
2/24/2012 | 11-0074 | All-Med v. Randolph Engineering Co., etc.(Workman, J. dissenting) | TCR | SEP
2/24/2012 | 11-0074 | All-Med v. Randolph Engineering Co., etc. | TCR | PC
2/24/2012 | 11-0315 | National Union Fire Ins. v. Jennifer Miller, etc. | TCR | PC
2/24/2012 | 11-0361 | State of West Virginia v. Donald Surber | CR-F | PC
2/24/2012 | 11-0120 & 11-0457 | State of West Virginia v. Paula D. Hoston, etc. | CR-F | SO
2/24/2012 | 11-1514 | SER Massachusetts Mutual Life Ins. v. Hon. David Sanders, et al. | OJ-P | SO
2/24/2012 | 101372 | Larry D. Butcher v. W. Va. Office of Insurance Commissioner/J.E.T. Resources | WC | MD
2/24/2012 | 101370 | Bernadette K. Shaw v. W. Va. Office of Insurance Commissioner/Morgan Co. Board of Ed. | WC | MD
2/24/2012 | 101362 | Joseph Scalise v. W. Va. Office of Insurance Commissioner/Wheeling Island Gaming | WC | MD
2/24/2012 | 101360 | Ethel Vennum v. W. Va. Office of Insurance Commissioner/Homer Laughlin China | WC | MD
2/24/2012 | 101358 | Joseph S. Dingus v. W. Va. Office of Insurance Commissioner/Greif Brothers Corp. | WC | MD
2/24/2012 | 101312 | Betty J. Nease v. W. Va. Office of Insurance Commissioner/Morgans Restaurants | WC | MD
2/24/2012 | 101305 | Danny Kennedy v. W. Va. Office of Insurance Commissioner/Appalachian Power | WC | MD
2/23/2012 | 11-0679 | Shawn Romano v. Wendy Greve | FAM | PC
2/23/2012 | 11-0342 | State of West Virginia v. Kendra Sulick | CR-F | SO
2/22/2012 | 11-0442 | Harrison L. Epperly v. W. Va. Office of Insurance Commissioner/Apogee Coal | WC | MD
2/22/2012 | 101386 | Charles S. Stone v. W. Va. Office of Insurance Commissioner/Huntington Alloys | WC | MD
2/22/2012 | 101384 | Harrison L. Epperly v. W. Va. Office of Insurance Commissioner/Apogee Coal | WC | MD
2/22/2012 | 101383 | Gerald R. Jenkins v. W. Va. Office of Insurance Commissioner/Consolidation Coal | WC | MD
2/22/2012 | 101382 | Thomas L. Cooper v. W. Va. Office of Insurance Commissioner/Appalachian Power | WC | MD
2/22/2012 | 101375 | Rennie D. Pauley v. W. Va. Office of Insurance Commissioner/Charleston Area Medical Center | WC | MD
2/22/2012 | 101374 | James A. Lawson v. W. Va. Office of Insurance Commissioner/ACF Industries | WC | MD
2/22/2012 | 101373 | James A. Milam, Jr. v. W. Va. Office of Insurance Commissioner/Essential Fuels | WC | MD
2/22/2012 | 101361 | John D. Wood v. W. Va. Office of Insurance Commissioner/Performance Coal | WC | MD
2/17/2012 | 101397 | D'Mitri L. Beverly v. W. Va. Office of Insurance Commissioner/W. Va. Division of Highways | WC | MD
2/17/2012 | 101396 | Pamela S. Harding v. W. Va. Office of Insurance Commissioner/Mayflower Vehicle Systems, Inc. | WC | MD
2/17/2012 | 101395 | Mary J. Walter v. W. Va. Office of Insurance Commissioner | WC | MD
2/17/2012 | 101394 | Donald R. Spaun v. W. Va. Office of Insurance Commissioner/Century Aluminum of WV, Inc. | WC | MD
2/17/2012 | 101393 | Billy J. McClanahan v. W. Va. Office of Insurance Commissioner/Nichols Construction, LLC | WC | MD
2/17/2012 | 101392 | Mary Gannon v. W. Va. Office of Insurance Commissioner/Perry & Hylton, Inc. | WC | MD
2/17/2012 | 101391 | Bruce E. Benedum v. W. Va. Office of Insurance Commissioner/Mosites Construction Company | WC | MD
2/17/2012 | 101390 | Ricky D. Thomas v. W. Va. Office of Insurance Commissioner/Century Aluminum of WV, Inc. | WC | MD
2/17/2012 | 101385 | Consolidation Coal Company v. W. Va. Office of Insurance Commissioner/James D. White | WC | MD
2/17/2012 | 101359 | Jackie L. Snodgrass v. W. Va. Office of Insurance Commissioner/Kroger Limited Partnership | WC | MD
2/15/2012 | 101252 | Linda A. Wall v. W. Va. Office of Insurance Commissioner/Mercer Co. Board of Education | WC | MD
2/15/2012 | 101253 | William E. Kendrick v. W. Va. Office of Insurance Commissioner/Gapco Mining | WC | MD
2/15/2012 | 101258 | Betty Estep v. W. Va. Office of Insurance Commissioner/Plott & Holbook, Inc. | WC | MD
2/14/2012 | 11-0387 | State of West Virginia v. Steve E. Blankenship | CR-M | MD
2/14/2012 | 11-0504 | J.B. v. K.C. and L.C. | FAM | MD
2/14/2012 | 11-0413 | Stoney G. Riley v. Adrian Hoke, Warden | CIV-O | MD
2/14/2012 | 11-0530 | SER Steve A. Watkins v. Jim Rubenstein, Commissioner | CIV-O | MD
2/14/2012 | 11-0133 | State of West Virginia v. Jack Conner | CR-F | MD
2/14/2012 | 11-0548 | State of West Virginia v. Henry Howard Jenkins | CR-F | MD
2/14/2012 | 11-0468 | State of West Virginia v. R.T. | CR-F | MD
2/14/2012 | 11-0342 | State of West Virginia v. Gerald Wayne Little | CR-F | MD
2/14/2012 | 11-0129 | Robert Allen Hager v. Thomas McBride, Warden | CIV-O | MD
2/14/2012 | 11-0462 | State of West Virginia v. Stephanie D. Pauley | CR-F | MD
2/14/2012 | 11-0056 | Agnieszka Collins v. Barbara L. Stewart, et al. | TCR | MD
2/14/2012 | 11-0146 | State of West Virginia v. Megan Ryman | CR-F | MD
2/14/2012 | 11-0563 | State of West Virginia v. Scott E. Minnick | CR-F | MD
2/14/2012 | 11-0458 | State of West Virginia v. Roger A. McKinney | CR-F | MD
2/14/2012 | 11-0661 | Frances A. Preast v. Burl Keith Skaggs, et al. | ADM | MD
2/14/2012 | 11-0077 | D.C. v. Wayne Co. Board of Education | ADM | MD
2/14/2012 | 11-0185 | Dean Miner v. Ricardo Pacheco | TCR | MD
2/14/2012 | 11-0278 | Mitch Nelson v. Board of Education of Boone Co. | ADM | MD
2/14/2012 | 11-0650 | Kathy S. Lefler v. W. Va. Dept. of Education | ADM | MD
2/13/2012 | 11-1405 & 11-1447, etc. | SER Thornton Cooper v. Natalie E. Tennant, Sec. of State, etc. | OJ-M | SO
2/13/2012 | 11-0596 | Sanford D. Creameans v. Christopher D. Chiles, Pros. Attorney | CIV-O | MD
2/13/2012 | 11-0874 | State of West Virginia v. Matthew Jonathan Robey | CR-F | MD
2/13/2012 | 11-0619 | State of West Virginia v. Michelle Bryant | CR-F | MD
2/13/2012 | 11-0570 | Dana and Nancy Singleton v. Citizens Bank of Weston | TCR | MD
2/13/2012 | 11-0966 | In Re: J.S. and K.S. | JUV | MD
2/13/2012 | 11-0930 | In Re: A.S. and W.M. | JUV | MD
2/13/2012 | 11-0913 | In Re: E.M. | JUV | MD
2/13/2012 | 11-0860 | In Re: A.M., S.M. and B.B. | JUV | MD
2/13/2012 | 11-0690 | State of West Virginia v. Brian Keith Hubbard | CR-F | MD
2/13/2012 | 11-0636 | State of West Virginia v. Dustin Chad Reed | CR-F | MD
2/13/2012 | 11-0534 | State of West Virginia v. Sherri Wukeson | CR-F | MD
2/13/2012 | 11-0545 | Samuel P. Sommerville, et al. v. Robert B. Rausenberger | TCR | MD
2/13/2012 | 11-1366 | In Re: I.F. and I.C. | JUV | MD
2/13/2012 | 11-1347 | In Re: S.B. and D.B. | JUV | MD
2/13/2012 | 11-1311 | In Re: D.B., F.B. and T.S. | JUV | MD
2/13/2012 | 11-1242 | In Re: S.O. | JUV | MD
2/13/2012 | 11-0724 | In Re: the Matter of J.B. and J.B. | FAM | MD
2/13/2012 | 11-0918 | State of West Virginia v. Danny Honaker, Jr. | CR-F | MD
2/13/2012 | 11-0835 | State of West Virginia v. Miguel Perez | CR-F | MD
2/13/2012 | 11-0825 | State of West Virginia v. John Payne | CR-F | MD
2/13/2012 | 11-0760 | State of West Virginia v. Joseph Suber | CR-F | MD
2/13/2012 | 11-0714 | State of West Virginia v. Thomas Eugene Gardner, Jr. | CR-F | MD
2/13/2012 | 11-0633 | State of West Virginia v. David L. Hunter | CR-F | MD
2/13/2012 | 11-0562 | State of West Virginia v. Larry E. Mayle, Jr. | CR-F | MD
2/13/2012 | 11-0829 | William Nesbitt v. Shannon Markle, Administrator | CIV-O | MD
2/13/2012 | 11-0852 | Melissa Dixon v. Estate of Faye Hudson, etc. | PR | MD
2/10/2012 | 11-1358 & 11-1360 | SER W. Va. Dept. of Transportation v. Hon. Jeffrey B. Reed (Workman, J. dissenting) | OJ-P | SEP
2/10/2012 | 11-1358 & 11-1360 | SER W. Va. Dept. of Transportation v. Hon. Jeffrey B. Reed | OJ-P | SO
2/10/2012 | 11-0073 | In Re: The Marriage of: Zickefoose v. Zickefoose(Workman, J. concurring, in part, and dissenting, in part) | FAM | SEP
2/10/2012 | 11-0073 | In Re: The Marriage of: Zickefoose v. Zickefoose | FAM | SO
2/10/2012 | 11-1404 | SER Coal Age, Inc. v. Hon. Warren R. McGraw, et al. | CIV-O | MD
2/10/2012 | 11-0257 | John S. Shannon v. City of Hurricane, et al. | CIV-O | MD
2/10/2012 | 11-0277 | Gregory Allan Zerkel v. Dana C. Zerkel n/k/a Leech | FAM | MD
2/10/2012 | 11-0211 | State of West Virginia v. Freddie Lee Bragg | CR-F | MD
2/10/2012 | 11-0599 | State of West Virginia v. Kenneth Lenhart | CR-F | MD
2/10/2012 | 11-1627 | SER Baker Installation v. Hon. Carrie Webster, Judge | OJ-M | MD
2/9/2012 | 11-0397 | Katy Addair v. Litwar Processing Co. | TCR | MD
2/9/2012 | 11-0248 & 11-0701 | Shenandoah Sales v. Assessor of Jefferson Co., etc | ADM | SO
2/9/2012 | 11-1260 | Big Lots Stores v. Rebecca and Kevin Arbogast | TCR | PC
1/20/2012 | 101347 | Marvin Shawn Bench v. W. Va. Office of Insurance Commissioner/Spartan Mining | WC | MD
1/19/2012 | 101172 | Danny L. Boyles v. W. Va. Office of Insurance Commissioner/Turn 4 Truck and Auto | WC | MD
1/19/2012 | 101116 | Jeana L. Hicks v. W. Va. Office of Insurance Commissioner/Westmoreland Coal | WC | MD
1/19/2012 | 101102 | Shirley Snyder v. W. Va. Office of Insurance Commissioner//Bayer Corp. | WC | MD
1/19/2012 | 101071 | Michael F. Estremera v. W. Va. Office of Insurance Commissioner/Royal Harvest | WC | MD
1/19/2012 | 101060 | Roger L. Harris v. W. Va. Office of Insurance Commissioner/Patriot Mining | WC | MD
1/19/2012 | 100965 | Richard D. Spurlock v. W. Va. Office of Insurance Commissioner/Appalachian Power | WC | MD
1/19/2012 | 101561 | Richard D. Spurlock v. W. Va. Office of Insurance Commissioner/Appalachian Power | WC | MD
1/27/2012 | 11-0565 | Steven M. Posey and Michelle E. Posey v. City of Buckhannon | TCR | SO
1/19/2012 | 11-0206 | Albert Postlewait, Jr. v. City of Wheeling | TCR | SO
1/19/2012 | 11-0206 | Albert Postlewait, Jr. v. City of Wheeling (Davis, J. dissenting) | TCR | SEP
1/19/2012 | 11-0399 | State of West Virginia v. Timothy Michael Waldron | CR-F | SO
1/19/2012 | 11-0191 | William Watson Jr. v. W. Va. DHHR and Mildred-Mitchell Bateman Hospital | ADM | MD
1/18/2012 | 11-1080 | In Re: S.M. and F.M. | JUV | MD
1/18/2012 | 11-1079 | In Re: S.M. and F.M. | JUV | MD
1/18/2012 | 11-1210 | In Re: R.P. | JUV | MD
1/18/2012 | 11-1227 | In Re: J. O. and I.O. | JUV | MD
1/18/2012 | 11-1087 | In Re: A.W. | JUV | MD
1/18/2012 | 11-1040 | In Re: D.D. | JUV | MD
1/18/2012 | 11-1027 | In Re: B.C., C.C. and A.C. | JUV | MD
1/18/2012 | 11-0951 | In Re: E.B. | JUV | MD
1/18/2012 | 11-1137 | In Re: T.C., J.C., V.C., A.C., C.C., C.C. and E.C. | JUV | MD
1/18/2012 | 11-0696 | In Re: I.G., L.G., J.H., G.N. III, and T.N. | JUV | MD
1/18/2012 | 11-0798 | In Re: B.D. | JUV | MD
1/18/2012 | 11-0807 | In Re: B.D. | JUV | MD
1/18/2012 | 11-0834 | In Re: K.M. | JUV | MD
1/18/2012 | 11-0907 | In Re: K.S. | JUV | MD
1/18/2012 | 11-0317 | State of West Virginia v. Shawn McCamick | CR-F | MD
1/13/2012 | 101278 | Donald Roger Layne v. Evelyn Siefert, Warden | CIV-O | MD
1/13/2012 | 101602 | Richard E. Smallwood v. Patrick Smallwood | PR | MD
1/13/2012 | 101615 | Jennifer J. Grafton-Gore v. Centra Bank | TCR | MD
1/13/2012 | 101573 | Robert Sanchez v. Tod Benson | TCR | MD
1/13/2012 | 11-0597 | Marlon Ferguson v. Nicholas J. Wall | TCR | MD
1/13/2012 | 11-1209 | Marlon Ferguson v. Kevin Hensel, etc. | TCR | MD
1/13/2012 | 11-0911 | Jeremy Toler v. Roger W. Goff | PR | MD